==> knative-model-6.3.1-sources.jar: io/fabric8/knative/flows/v1/SequenceFluentImpl.java <==
package io.fabric8.knative.flows.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SequenceFluentImpl<A extends SequenceFluent<A>> extends BaseFluent<A> implements SequenceFluent<A>{
  public SequenceFluentImpl() {
  }
  public SequenceFluentImpl(Sequence instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SequenceSpecBuilder spec;
  private SequenceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SequenceFluent.MetadataNested<A> withNewMetadata() {
    return new SequenceFluentImpl.MetadataNestedImpl();
  }
  public SequenceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SequenceFluentImpl.MetadataNestedImpl(item);
  }
  public SequenceFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SequenceFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SequenceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SequenceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SequenceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SequenceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SequenceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public SequenceFluent.SpecNested<A> withNewSpec() {
    return new SequenceFluentImpl.SpecNestedImpl();
  }
  public SequenceFluent.SpecNested<A> withNewSpecLike(SequenceSpec item) {
    return new SequenceFluentImpl.SpecNestedImpl(item);
  }
  public SequenceFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SequenceFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SequenceSpecBuilder().build());
  }
  public SequenceFluent.SpecNested<A> editOrNewSpecLike(SequenceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SequenceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SequenceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SequenceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SequenceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public SequenceFluent.StatusNested<A> withNewStatus() {
    return new SequenceFluentImpl.StatusNestedImpl();
  }
  public SequenceFluent.StatusNested<A> withNewStatusLike(SequenceStatus item) {
    return new SequenceFluentImpl.StatusNestedImpl(item);
  }
  public SequenceFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SequenceFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SequenceStatusBuilder().build());
  }
  public SequenceFluent.StatusNested<A> editOrNewStatusLike(SequenceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SequenceFluentImpl that = (SequenceFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SequenceFluent.MetadataNested<N>> implements SequenceFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SequenceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SequenceSpecFluentImpl<SequenceFluent.SpecNested<N>> implements SequenceFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SequenceSpec item) {
      this.builder = new SequenceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SequenceSpecBuilder(this);
    }
    SequenceSpecBuilder builder;
    public N and() {
      return (N) SequenceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SequenceStatusFluentImpl<SequenceFluent.StatusNested<N>> implements SequenceFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SequenceStatus item) {
      this.builder = new SequenceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SequenceStatusBuilder(this);
    }
    SequenceStatusBuilder builder;
    public N and() {
      return (N) SequenceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/SequenceFluentImpl.java <==
package io.fabric8.knative.flows.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SequenceFluentImpl<A extends SequenceFluent<A>> extends BaseFluent<A> implements SequenceFluent<A>{
  public SequenceFluentImpl() {
  }
  public SequenceFluentImpl(Sequence instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SequenceSpecBuilder spec;
  private SequenceStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SequenceFluentImpl.MetadataNested<A> withNewMetadata() {
    return new SequenceFluentImpl.MetadataNestedImpl();
  }
  public SequenceFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SequenceFluentImpl.MetadataNestedImpl(item);
  }
  public SequenceFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SequenceFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SequenceFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SequenceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SequenceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SequenceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SequenceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public SequenceFluentImpl.SpecNested<A> withNewSpec() {
    return new SequenceFluentImpl.SpecNestedImpl();
  }
  public SequenceFluentImpl.SpecNested<A> withNewSpecLike(SequenceSpec item) {
    return new SequenceFluentImpl.SpecNestedImpl(item);
  }
  public SequenceFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SequenceFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SequenceSpecBuilder().build());
  }
  public SequenceFluentImpl.SpecNested<A> editOrNewSpecLike(SequenceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SequenceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SequenceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SequenceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SequenceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public SequenceFluentImpl.StatusNested<A> withNewStatus() {
    return new SequenceFluentImpl.StatusNestedImpl();
  }
  public SequenceFluentImpl.StatusNested<A> withNewStatusLike(SequenceStatus item) {
    return new SequenceFluentImpl.StatusNestedImpl(item);
  }
  public SequenceFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SequenceFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SequenceStatusBuilder().build());
  }
  public SequenceFluentImpl.StatusNested<A> editOrNewStatusLike(SequenceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SequenceFluentImpl that = (SequenceFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SequenceFluentImpl.MetadataNested<N>> implements SequenceFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SequenceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SequenceSpecFluentImpl<SequenceFluentImpl.SpecNested<N>> implements SequenceFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SequenceSpec item) {
      this.builder = new SequenceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SequenceSpecBuilder(this);
    }
    SequenceSpecBuilder builder;
    public N and() {
      return (N) SequenceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SequenceStatusFluentImpl<SequenceFluentImpl.StatusNested<N>> implements SequenceFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SequenceStatus item) {
      this.builder = new SequenceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SequenceStatusBuilder(this);
    }
    SequenceStatusBuilder builder;
    public N and() {
      return (N) SequenceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
